@@ -23,7 +23,6 @@
 #include "GlobalBindings.hxx"
 #include "ncmpc.hxx"
 #include "Point.hxx"
-#include "util/Compiler.h"
 
 static bool
 ignore_key(int key)
@@ -31,7 +30,7 @@ ignore_key(int key)
 	return key == ERR || key == '\0';
 }
 
-gcc_pure
+[[gnu::pure]]
 static Command
 translate_key(int key)
 {
@@ -79,7 +78,7 @@ AsyncUserInput::OnSocketReady(unsigned) noexcept
 
 AsyncUserInput::AsyncUserInput(EventLoop &event_loop, WINDOW &_w) noexcept
 	:socket_event(event_loop, BIND_THIS_METHOD(OnSocketReady),
-		      SocketDescriptor(STDIN_FILENO)),
+		      FileDescriptor{STDIN_FILENO}),
 	 w(_w)
 {
 	socket_event.ScheduleRead();
