@@ -1,6 +1,5 @@
 /* ncmpc (Ncurses MPD Client)
- * (c) 2004-2020 The Music Player Daemon Project
- * Project homepage: http://musicpd.org
+ * Copyright 2004-2021 The Music Player Daemon Project
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -186,6 +185,10 @@ static constexpr command_definition_t cmds[] = {
 	{ "search-mode",
 	  N_("Change search mode") },
 #endif
+#ifdef ENABLE_PLAYLIST_EDITOR
+	{ "playlist-editor-page",
+	  N_("Playlist editor") },
+#endif
 #ifdef ENABLE_SONG_SCREEN
 	{ "view",
 	  N_("View the selected and the currently playing song") },
@@ -199,8 +202,8 @@ static constexpr command_definition_t cmds[] = {
 	  N_("Interrupt action") },
 	{ "lyrics-update",
 	  N_("Update Lyrics") },
-	/* this command may move out of #ifdef ENABLE_LYRICS_SCREEN
-	   at some point */
+#endif
+#if defined(ENABLE_LYRICS_SCREEN) || defined(ENABLE_PLAYLIST_EDITOR)
 	{ "edit",
 	  N_("Edit the current item") },
 #endif
