@@ -226,7 +226,7 @@ class HelpPage final : public ListPage, ListRenderer, ListText {
 public:
 	HelpPage(ScreenManager &_screen, WINDOW *w, Size size)
 		:ListPage(w, size), screen(_screen) {
-		lw.DisableCursor();
+		lw.HideCursor();
 		lw.SetLength(std::size(help_text));
 	}
 
@@ -274,13 +274,14 @@ help_init(ScreenManager &screen, WINDOW *w, Size size)
 void
 HelpPage::PaintListItem(WINDOW *w, unsigned i,
 			unsigned y, unsigned width,
-			gcc_unused bool selected) const noexcept
+			bool selected) const noexcept
 {
 	const auto *row = &help_text[i];
 
 	assert(i < std::size(help_text));
 
-	row_color(w, row->highlight ? Style::LIST_BOLD : Style::LIST, false);
+	row_color(w, row->highlight ? Style::LIST_BOLD : Style::LIST,
+		  selected);
 
 	wclrtoeol(w);
 
@@ -316,10 +317,14 @@ HelpPage::OnCommand(struct mpdclient &c, Command cmd)
 	if (ListPage::OnCommand(c, cmd))
 		return true;
 
-	lw.SetCursorFromOrigin(0);
+	if (!lw.IsCursorVisible())
+		/* start searching at the beginning of the page (not
+		   where the invisible cursor just happens to be),
+		   unless the cursor is still visible from the last
+		   search */
+		lw.SetCursorFromOrigin(0);
+
 	if (screen_find(screen, lw, cmd, *this)) {
-		/* center the row */
-		lw.Center(lw.GetCursorIndex());
 		SetDirty();
 		return true;
 	}
