@@ -49,8 +49,7 @@ ScreenManager::ScreenManager(EventLoop &event_loop) noexcept
 #ifdef ENABLE_COLORS
 	if (options.enable_colors) {
 		/* set background attributes */
-		wbkgd(stdscr, COLOR_PAIR(Style::LIST));
-		wbkgd(main_window.w, COLOR_PAIR(Style::LIST));
+		main_window.SetBackgroundStyle(Style::LIST);
 	}
 #endif
 }
